@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -76,7 +76,7 @@ char * uSocket = NULL;
 
 static char * btAddress = NULL;
 
-int bt_open_port(char* port) 
+int openSerialPort(char* port) 
 {
 	
 	/* get a file descriptor */
@@ -136,11 +136,11 @@ int bt_open_port(char* port)
 }
 
 // Then port will be closed from a forked child use 0
-int bt_close_port(int final) 
+int closeSerialPort(int final) 
 {
 	int retval = 0;
 	
-	logger("INF", "bt_close_port");
+	logger("INF", "closeSerialPort");
 
 	if (!portfd) { /* already closed */
 		if (final) logger("INF", "Already closed ?");
@@ -163,6 +163,46 @@ int bt_close_port(int final)
 	return retval;
 }
 
+//
+// RFCOMM socket handling
+//
+
+int rfcommConnect(const char *addr, int channel)
+{
+	if (portfd >= 0) {
+		rfcommClose();	
+	}
+	#ifdef USE_BLUEZ
+		
+	struct sockaddr_rc bt_addr = { 0 };
+
+	bt_addr.rc_family  = AF_BLUETOOTH;
+	bt_addr.rc_channel = (uint8_t) channel;
+	str2ba(addr, &(bt_addr.rc_bdaddr)); 
+
+	if ((portfd = socket(AF_BLUETOOTH, SOCK_STREAM|SOCK_CLOEXEC, BTPROTO_RFCOMM)) < 0) {
+		logger("ERR", "opening socket");
+		printf("ERROR: opening socket\n");
+	
+		return -1;
+	}
+	
+	connect(portfd, (struct sockaddr *) &bt_addr, sizeof(bt_addr));
+	
+	#endif
+	
+	return portfd;
+}
+
+void rfcommClose(void)
+{
+	if (portfd >= 0) {
+		shutdown(portfd, SHUT_RDWR);
+		portfd = -1;
+	}
+}
+
+
 int bt_read(char* buf, int len) 
 {
 	return read(portfd, buf, len);
@@ -234,7 +274,7 @@ int  bt_readchar(char* c, int timeout)
 	if (rv == 0) return EOF - 1;
 	
 	//  else - EOF
-	bt_close_port(0);
+	closeSerialPort(0);
 	return EOF;
 }
 
