@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -22,8 +22,12 @@
 #ifndef _BTIO_H
 #define _BTIO_H
 
-int  bt_open_port(char* port);
-int  bt_close_port(int final);
+int  rfcommConnect(const char* btAddress, int channel);
+void rfcommClose(void);
+
+int  openSerialPort (char* port);
+int  closeSerialPort(int final);
+
 
 int  bt_read(char* buf, int len);
 int  bt_readchar(char* c, int timeout);
