@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,8 +37,8 @@
 #define SEND_BYTES      "bytes"
 
 void	setToFile	(void);
-void 	handleCmdByKey  (type_key* k, cmdParams *p);
-void    handleCmdByKeyEx(type_key* k, cmdParams* p, int sendToMain);
+int  	handleCmdByKey  (type_key* k, cmdParams *p);
+int     handleCmdByKeyEx(type_key* k, cmdParams* p, int sendToMain);
 int 	processCommands (cmdItem* cmdList, cmdParams *p);
 int 	execDynamically (char *command);
 void	flushOldConf	(void);
