@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@
   
 #define IS_OK(answer) (strstr(answer, "OK") != NULL)
 
-#define AT_DEVICE   	"at:"
+#define AT_DEVICE   	"rfcomm"
 #define INET_SOCKET   	"socket:"
 #define BT_SOCKET   	"bluetooth"
 #define BT_SPP   	"btspp" 	// not yet used
@@ -49,16 +49,18 @@
 #define TOFILE   	"/anyremote.result"
 #define CMDFILE   	"/anyremote.command"
 
-#define CLIENT_AT       0	// AT protocol
-#define SERVER_TCP      1	// anyRemote protocol over TCP/IP
-#define SERVER_BT       2	// anyRemote protocol over btspp
-#define CLIENT_ILIRC    3	// inputLirc protocol
-#define SERVER_UX       4       // NOT USED: anyRemote protocol over IR (or any AF_UNIX socket) - as server
-#define CLIENT_NOAT     5	// anyRemote protocol over IR (or any AF_UNIX socket) - as client
-#define SERVER_STDIN    6	// anyRemote protocol, read command from stdin
-#define SERVER_L2CAP    7	// anyRemote protocol over l2cap
+#define CLIENT_RFCOMM   0	// AT protocol over bluetooth
+#define CLIENT_AT       1	// AT protocol over IR or cable
+#define SERVER_TCP      2	// anyRemote protocol over TCP/IP
+#define SERVER_BT       3	// anyRemote protocol over btspp
+#define CLIENT_ILIRC    4	// inputLirc protocol
+#define SERVER_UX       5       // NOT USED: anyRemote protocol over IR (or any AF_UNIX socket) - as server
+#define CLIENT_NOAT     6	// anyRemote protocol over IR (or any AF_UNIX socket) - as client
+#define SERVER_STDIN    7	// anyRemote protocol, read command from stdin
+#define SERVER_L2CAP    8	// TODO: anyRemote protocol over l2cap
 
 #define DEFAULT_BT_CHANNEL 19
+#define BT_ADDR_LEN        17   // 00:12:EF:32:21:1A
 #define DEFAULT_L2CAP_PORT 5019
 
 #ifndef SOCK_CLOEXEC
