@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -68,7 +68,7 @@ int  callOn       = 0;
 
 int  gotExitSignal  = 0;
 
-int  serverMode   = CLIENT_AT;  // By default use AT commands and devices in /dev
+int  serverMode   = SERVER_BT;  // By default use anyRemote protocol over btspp
 
 int  port         = 0;
 static int  initialized  = 0;
@@ -84,7 +84,11 @@ int openPort(char * portIn)
         int ret = 0;
 
         // device should be in format:
-        // 1. (AT mode)     /dev/something							used with AT mode commands
+        
+	// deprecated
+	// 1. (AT mode)     /dev/something							used with AT mode commands
+	
+	// 1. (AT mode)     rfcomm:00:12:EF:32:21:1A:xx (xx is integer from 1 to 32)
         // 2. (Server mode) socket:NNNN or 							used with java client
 	//                  socket:/path/to/socket						used with java client
         // 3. (Server mode) bluetooth:NN or bluetooth (port will be = DEFAULT_BT_CHANNEL) 	used with java client
@@ -188,7 +192,7 @@ int openPort(char * portIn)
 
         	DEBUG2("[DS]: Serial Client mode (no AT). Use device %s", strPort);
 
-                if (bt_open_port(strPort) < 0) {
+                if (openSerialPort(strPort) < 0) {
                 	printf("ERROR: open device\n");
                         return -1;
                 }
@@ -200,16 +204,45 @@ int openPort(char * portIn)
                 serverMode = SERVER_STDIN;
                 openStdin();
 
-        } else {	//if ((strPort = strstr(portIn, AT_DEVICE)) != NULL){
+        } else if ((strPort = strstr(portIn, AT_DEVICE)) != NULL){
 
         	DEBUG2("[DS]: Serial Client mode. Use device %s", portIn);
+		
+		if (!(strlen(portIn) == strlen(AT_DEVICE) + BT_ADDR_LEN + 3  || // 00:12:EF:32:21:1A:p
+		      strlen(portIn) == strlen(AT_DEVICE) + BT_ADDR_LEN + 4) || // 00:12:EF:32:21:1A:pp
+		    portIn[strlen(AT_DEVICE)] != ':' ||
+		    portIn[strlen(AT_DEVICE) + BT_ADDR_LEN + 1] != ':') {
+	        	printf("ERROR: Improper connect string !\n");
+	        	return -1;
+		}
+		
+		char sBtAddr[18];
+		int  btChannel = 0; 
+		
+		strncpy(sBtAddr,portIn + strlen(AT_DEVICE) + 1,17);
+		sBtAddr[17] = '\0';
+		
+		btChannel = atoi(portIn + strlen(AT_DEVICE) + BT_ADDR_LEN + 2);
+		
+		//printf("rfcommConnect() %s : %d\n", sBtAddr, btChannel);
+                if (rfcommConnect(sBtAddr,btChannel) < 0) {
+                	logger("ERR","[DS]: can not open RFCOMM channel \n");
+                        return -1;
+                }
 
-                if (bt_open_port(portIn) < 0) {
-                	logger("ERR","[DS]: can not open RFCOMM port\n");
+                serverMode = CLIENT_RFCOMM;
+       } else {
+        	DEBUG2("[DS]: Serial Client mode. Use device %s", portIn);
+
+                if (openSerialPort(portIn) < 0) {
+                	logger("ERR","[DS]: can not open serial port\n");
                         return -1;
                 }
                 serverMode = CLIENT_AT;
-        }
+  		
+		//printf("ERROR: Improper connect string !\n");
+	 	//return -1;
+	}
 
         return 1;
 }
@@ -247,9 +280,11 @@ void closePort(int final)
         	if (unix_close_port() < 0) {
                 	if (final) logger("ERR","[DS]: Error on closing AF_UNIX socket\n");
                 }
+        } else if (serverMode == CLIENT_RFCOMM) {
+		rfcommClose();
         } else if (serverMode == CLIENT_AT || serverMode == CLIENT_NOAT) {
-        	if (bt_close_port(final) < 0) {
-                	if (final) logger("ERR","[DS]: Error on closing port\n");
+        	if (closeSerialPort(final) < 0) {
+                      if (final) logger("ERR","[DS]: Error on closing port\n");
                 }
         } else if (serverMode == SERVER_STDIN && final) {
         	closeStdin();
@@ -299,7 +334,7 @@ static int proceedDisconnect(void)
 			canForceExit = 1;
 		}
 
-	} else if (serverMode == CLIENT_AT) {
+	} else if (serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT) {
 
 		sendCMER(CMER_OFF);
 		canForceExit = 1;
@@ -435,10 +470,11 @@ void parseCommand(char* cmd)
 	// if recieved multiline command - handle line by line and return
 	prev = cmd;
 	next = strchr(cmd, '\r');
-	if (next == NULL && serverMode != CLIENT_AT) {	// Java client will send +CKEV: 1,1; +CKEV: 1,0
+	if (next == NULL && 
+	    !(serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT)) {	// Java client will send +CKEV: 1,1; +CKEV: 1,0
 		next = strchr(cmd, ';');
 	}
-	if (next == NULL && serverMode != CLIENT_AT) {
+	if (next == NULL && !(serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT)) {
 		next = strchr(cmd, '\3');		// end-of-text marker in CommandFusion
 	}
 	if (next) {
@@ -459,10 +495,12 @@ void parseCommand(char* cmd)
 			}
 			prev = next+1;
 			next = strchr(prev, '\r');
-			if (next == NULL && serverMode != CLIENT_AT) {	// Java client will send +CKEV: 1,1; +CKEV: 1,0
+			if (next == NULL && 
+			    !(serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT)) { // Java client will send +CKEV: 1,1; +CKEV: 1,0
 				next = strchr(prev, ';');
 			}
-			if (next == NULL && serverMode != CLIENT_AT) {	
+			if (next == NULL && 
+			    !(serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT)) {	
 				next = strchr(prev, '\3');		// end-of-text marker in CommandFusion
 			}
 		} while (next) ;
@@ -681,7 +719,6 @@ gpointer dispatcherRoutine(gpointer thread)
 {
 	char answer[MAXCMDLEN];
 	int ret = EXIT_OK;
-	int retRead = 0;
 
 	logger("DBG","[DS]: start dispatcher thread");
 
@@ -705,6 +742,7 @@ gpointer dispatcherRoutine(gpointer thread)
 	
 	while (1) {
 	
+	        int retRead = 0;
 		char* dv = getDevice();
 		
 		logger("DBG","[DS]: ************ outer loop **********");
@@ -713,6 +751,8 @@ gpointer dispatcherRoutine(gpointer thread)
 		// try to open port
 		if(openPort(dv) == 1) {   // Open device
 		
+		    logger("DBG","[DS]: Device open OK");
+		
         	    if (initialized == 0) { 
 		    		    
 		        // setgid
@@ -729,12 +769,16 @@ gpointer dispatcherRoutine(gpointer thread)
 		    
 		    if (initPort() == 1 ) {  // Init modem: AT, ATE0, AT+CMER, in server mode waits for connection
 
+                        logger("DBG","[DS]: Init connection OK");
+			
  		        dispIsJoinable = TRUE;
 		       
                         isConnected = 1;
                         
 			if (usePassword()) {
 			
+			        logger("DBG","[DS]: Do password verification");
+				
 				char *pass = getStoredPass();
 				if (pass) {
 				        int gotReply = 1;
@@ -800,6 +844,7 @@ gpointer dispatcherRoutine(gpointer thread)
 				} else {
 					logger("DBG","[DS]: No password specified. Skip check.");
 				}
+				logger("DBG","[DS]: Password verification OK");
 			}
 			
 			if (retRead != EOF) {
@@ -831,8 +876,9 @@ gpointer dispatcherRoutine(gpointer thread)
 						sendDisconnect();
 						sendEventToExecutor(ID_EVT_DISCONNECT);
 						    		    
-	    					if (serverMode == CLIENT_AT    || 
-					    	    serverMode == CLIENT_ILIRC || 
+	    					if (serverMode == CLIENT_RFCOMM || 
+					    	    serverMode == CLIENT_AT     || 
+					    	    serverMode == CLIENT_ILIRC  || 
 					            serverMode == CLIENT_NOAT) {  // In server mode we will reuse already opened socket
 					    
 	    		    				logger("INF", "[DS]: Closing the port");
@@ -882,10 +928,15 @@ gpointer dispatcherRoutine(gpointer thread)
 	    	    			// Main loop timer (1/50 of second)
 		    			usleep(20000);
 		 		}
-			}   	// not EOF after password verification
-		    }		// init port
-		}		// open port
-		
+			} else {  	// not EOF after password verification
+			  	logger("DBG","[DS]: Connection EOF");
+			}
+		    } else {		// init port
+		        logger("DBG","[DS]: Init connection error");
+		    }
+		} else {		// open port
+		    logger("DBG","[DS]: Device open error");
+		}
 		free(dv);
 		
 		//printf("Connection closed or lost\n");
