@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -412,7 +412,7 @@ static int handle_key_press(char* key,int isRepeatable)
                         strcpy(modifierString, key);
                 } 
 
-                if(serverMode == CLIENT_AT) {
+                if(serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT) {
 			sendToMainMenu();
                 }
         } else if (k && i == FLAG_PARAMETR){
@@ -426,7 +426,7 @@ static int handle_key_press(char* key,int isRepeatable)
         } else {
         	// User had pressed some key ... 
                 // Send ToMainMenu sequence of CKPD's to show main menu again
-                if (serverMode == CLIENT_AT) {
+                if (serverMode == CLIENT_RFCOMM || serverMode == CLIENT_AT) {
                 	sendToMainMenu();
                 }
 
@@ -626,8 +626,8 @@ static int isBemusedCommand(char *cmdIn)
         	int handle = 0;
                 int shift  = 4;
 
-                char oneCmd[10];
-		memset(oneCmd,0,10);
+                char oneCmd[16];
+		memset(oneCmd,0,16);
 		
                 char paramValue[8];
                 paramValue[0] = '\0';
