@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -182,7 +182,8 @@ gboolean adminRoutine(gpointer data)
 			logger("DBG","[ML]: got disconnect request");
 			
 			if (!autoConnect() &&
-			    (serverMode == CLIENT_AT || 
+			    (serverMode == CLIENT_RFCOMM ||
+			     serverMode == CLIENT_AT     || 
 			     serverMode == CLIENT_ILIRC)) {
 			        logger("DBG","[ML]: Exit because of disconnect");
 				aboutToExit();	// exit here 
