@@ -2,7 +2,7 @@
 // anyRemote
 // a bluetooth remote for your PC.
 //
-// Copyright (C) 2006,2007,2008,2009,2010 Mikhail Fedotov <anyremote@mail.ru>
+// Copyright (C) 2006-2011 Mikhail Fedotov <anyremote@mail.ru>
 // 
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -200,20 +200,34 @@ timerCmd* findTimer(char *id, timerCmd **prev)
 
 timerCmd* createTimer(cmdItem *ci)
 {
+        //printf("createTimer\n");
 	if (ci->descr == NULL || ci->descr[0] == '\0' || ci->tdata == NULL) {
         	logger("DBG", "createTimer(): wrong input");                
                 return NULL;
         }
-
+        //printf("createTimer %s\n", ci->descr);
         if (findTimer(ci->descr, NULL) != NULL) {
         	logger("DBG", "createTimer(): timer already exists");                
                 return NULL;
         } 
-        timerCmd *tm = calloc(sizeof(timerCmd),1);
+        timerCmd *tm = calloc(1,sizeof(timerCmd));
 
         tm->ticks     = 0;
         tm->times     = 1;
-        tm->timer     = ci;
+	cmdItem* dup  = calloc(1, sizeof(cmdItem));
+        
+	dup->type  = ci->type;
+        dup->descr = (char*) calloc(1, strlen(ci->descr)+1);
+	strcpy(dup->descr, ci->descr);
+        
+	dup->tdata = (timerData*) calloc(1, sizeof(timerData));
+	dup->tdata->timeout = ci->tdata->timeout;
+	dup->tdata->times   = ci->tdata->times;
+	
+        dup->exec = NULL;
+        dup->next = NULL;
+	
+        tm->timer     = dup;
         tm->status    = TIMER_RUN;
 
         // Insert in head
@@ -224,7 +238,7 @@ timerCmd* createTimer(cmdItem *ci)
         }
         timers = tm;
 	
-        DEBUG2("createTimer(): timer created %s %d",tm->timer->descr,tm->timer->tdata->timeout);
+        DEBUG2("createTimer(): timer created (%p) (%p) %s %d",tm,tm->timer,tm->timer->descr,tm->timer->tdata->timeout);
 
         return tm;
 }
@@ -266,8 +280,9 @@ static void deleteTimer(char *id)
                 	logger("ERR", "Previous item absent for non-first element");
                         return;
                 }
-        }       
-	
+        } 
+	      
+	freeCmds(tm->timer);
 	tm->timer = NULL;
         free(tm);
 
@@ -293,17 +308,16 @@ extern void macroCmd(char *macro, cmdParams* params);
 void verifyTimers(int ticksInSec) 
 {
         //logger("DBG", "verifyTimers()");
-	
 	timerCmd *tm = timers;
 
         while (tm != NULL) {
 		timerCmd *tm_next = tm->next;
 		
                 if (tm->status == TIMER_RUN) {	// do not process paused timers
+			//DEBUG2("verifyTimers(): timer %p\n",tm);
 		        //DEBUG2("verifyTimers(): timer descr %s ", tm->timer->descr);
 		        //DEBUG2("verifyTimers(): timer ticks %d ", tm->ticks);
 		        //DEBUG2("verifyTimers(): timer tmout %d ", tm->timer->tdata->timeout);
-			
                 	if (tm->ticks >= (tm->timer->tdata->timeout * ticksInSec)) {
                 		DEBUG2("verifyTimers(): it is time to execute %s", tm->timer->descr);
 
@@ -572,7 +586,9 @@ void printHelp()
 	printf("    bluetooth:<channel> (Server mode - bluetooth connection)\n");
 	printf("    socket:<port>       (Server mode - TCP/IP connection)\n");
 	printf("    local:/dev/ircommX  (Server mode - IR connection)\n");
-	printf("    /dev/rfcomm#        (AT mode - bluetooth connection)\n");
+	printf("    rfcomm:XX:XX:XX:XX:XX:XX:CC (AT mode - bluetooth connection,\n");
+	printf("        where XX:XX:XX:XX:XX:XX is bluetooth device address,\n");
+	printf("        and CC is channel number - integer from 1 to 32)\n");
 	printf("    /dev/ttyACM#        (AT mode - cable connection)\n");
 	printf("    /dev/ircomm#        (AT mode - IR connection)\n");
 	printf("    ilirc:<AF_LOCAL socket file> (use with inputlircd)\n");
